from enum import Enum
import math
import string


class TemperatureGradientUnits(Enum):
        """
            TemperatureGradientUnits enumeration
        """
        
        KelvinPerMeter = 'kelvin_per_meter'
        """
            
        """
        
        DegreeCelsiusPerMeter = 'degree_celsius_per_meter'
        """
            
        """
        
        DegreeFahrenheitPerFoot = 'degree_fahrenheit_per_foot'
        """
            
        """
        
        DegreeCelsiusPerKilometer = 'degree_celsius_per_kilometer'
        """
            
        """
        

class TemperatureGradient:
    """
    None

    Args:
        value (float): The value.
        from_unit (TemperatureGradientUnits): The TemperatureGradient unit to create from, The default unit is KelvinPerMeter
    """
    def __init__(self, value: float, from_unit: TemperatureGradientUnits = TemperatureGradientUnits.KelvinPerMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__kelvins_per_meter = None
        
        self.__degrees_celcius_per_meter = None
        
        self.__degrees_fahrenheit_per_foot = None
        
        self.__degrees_celcius_per_kilometer = None
        

    def __convert_from_base(self, from_unit: TemperatureGradientUnits) -> float:
        value = self.__value
        
        if from_unit == TemperatureGradientUnits.KelvinPerMeter:
            return (value)
        
        if from_unit == TemperatureGradientUnits.DegreeCelsiusPerMeter:
            return (value)
        
        if from_unit == TemperatureGradientUnits.DegreeFahrenheitPerFoot:
            return ((value * 0.3048) * 9 / 5)
        
        if from_unit == TemperatureGradientUnits.DegreeCelsiusPerKilometer:
            return (value * 1e3)
        
        return None


    def __convert_to_base(self, value: float, to_unit: TemperatureGradientUnits) -> float:
        
        if to_unit == TemperatureGradientUnits.KelvinPerMeter:
            return (value)
        
        if to_unit == TemperatureGradientUnits.DegreeCelsiusPerMeter:
            return (value)
        
        if to_unit == TemperatureGradientUnits.DegreeFahrenheitPerFoot:
            return ((value / 0.3048) * 5 / 9)
        
        if to_unit == TemperatureGradientUnits.DegreeCelsiusPerKilometer:
            return (value / 1e3)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_kelvins_per_meter(kelvins_per_meter: float):
        """
        Create a new instance of TemperatureGradient from a value in kelvins_per_meter.

        

        :param meters: The TemperatureGradient value in kelvins_per_meter.
        :type kelvins_per_meter: float
        :return: A new instance of TemperatureGradient.
        :rtype: TemperatureGradient
        """
        return TemperatureGradient(kelvins_per_meter, TemperatureGradientUnits.KelvinPerMeter)

    
    @staticmethod
    def from_degrees_celcius_per_meter(degrees_celcius_per_meter: float):
        """
        Create a new instance of TemperatureGradient from a value in degrees_celcius_per_meter.

        

        :param meters: The TemperatureGradient value in degrees_celcius_per_meter.
        :type degrees_celcius_per_meter: float
        :return: A new instance of TemperatureGradient.
        :rtype: TemperatureGradient
        """
        return TemperatureGradient(degrees_celcius_per_meter, TemperatureGradientUnits.DegreeCelsiusPerMeter)

    
    @staticmethod
    def from_degrees_fahrenheit_per_foot(degrees_fahrenheit_per_foot: float):
        """
        Create a new instance of TemperatureGradient from a value in degrees_fahrenheit_per_foot.

        

        :param meters: The TemperatureGradient value in degrees_fahrenheit_per_foot.
        :type degrees_fahrenheit_per_foot: float
        :return: A new instance of TemperatureGradient.
        :rtype: TemperatureGradient
        """
        return TemperatureGradient(degrees_fahrenheit_per_foot, TemperatureGradientUnits.DegreeFahrenheitPerFoot)

    
    @staticmethod
    def from_degrees_celcius_per_kilometer(degrees_celcius_per_kilometer: float):
        """
        Create a new instance of TemperatureGradient from a value in degrees_celcius_per_kilometer.

        

        :param meters: The TemperatureGradient value in degrees_celcius_per_kilometer.
        :type degrees_celcius_per_kilometer: float
        :return: A new instance of TemperatureGradient.
        :rtype: TemperatureGradient
        """
        return TemperatureGradient(degrees_celcius_per_kilometer, TemperatureGradientUnits.DegreeCelsiusPerKilometer)

    
    @property
    def kelvins_per_meter(self) -> float:
        """
        
        """
        if self.__kelvins_per_meter != None:
            return self.__kelvins_per_meter
        self.__kelvins_per_meter = self.__convert_from_base(TemperatureGradientUnits.KelvinPerMeter)
        return self.__kelvins_per_meter

    
    @property
    def degrees_celcius_per_meter(self) -> float:
        """
        
        """
        if self.__degrees_celcius_per_meter != None:
            return self.__degrees_celcius_per_meter
        self.__degrees_celcius_per_meter = self.__convert_from_base(TemperatureGradientUnits.DegreeCelsiusPerMeter)
        return self.__degrees_celcius_per_meter

    
    @property
    def degrees_fahrenheit_per_foot(self) -> float:
        """
        
        """
        if self.__degrees_fahrenheit_per_foot != None:
            return self.__degrees_fahrenheit_per_foot
        self.__degrees_fahrenheit_per_foot = self.__convert_from_base(TemperatureGradientUnits.DegreeFahrenheitPerFoot)
        return self.__degrees_fahrenheit_per_foot

    
    @property
    def degrees_celcius_per_kilometer(self) -> float:
        """
        
        """
        if self.__degrees_celcius_per_kilometer != None:
            return self.__degrees_celcius_per_kilometer
        self.__degrees_celcius_per_kilometer = self.__convert_from_base(TemperatureGradientUnits.DegreeCelsiusPerKilometer)
        return self.__degrees_celcius_per_kilometer

    
    def to_string(self, unit: TemperatureGradientUnits = TemperatureGradientUnits.KelvinPerMeter) -> string:
        """
        Format the TemperatureGradient to string.
        Note! the default format for TemperatureGradient is KelvinPerMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == TemperatureGradientUnits.KelvinPerMeter:
            return f"""{self.kelvins_per_meter} ∆°K/m"""
        
        if unit == TemperatureGradientUnits.DegreeCelsiusPerMeter:
            return f"""{self.degrees_celcius_per_meter} ∆°C/m"""
        
        if unit == TemperatureGradientUnits.DegreeFahrenheitPerFoot:
            return f"""{self.degrees_fahrenheit_per_foot} ∆°F/ft"""
        
        if unit == TemperatureGradientUnits.DegreeCelsiusPerKilometer:
            return f"""{self.degrees_celcius_per_kilometer} ∆°C/km"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: TemperatureGradientUnits = TemperatureGradientUnits.KelvinPerMeter) -> string:
        """
        Get TemperatureGradient unit abbreviation.
        Note! the default abbreviation for TemperatureGradient is KelvinPerMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == TemperatureGradientUnits.KelvinPerMeter:
            return """∆°K/m"""
        
        if unit_abbreviation == TemperatureGradientUnits.DegreeCelsiusPerMeter:
            return """∆°C/m"""
        
        if unit_abbreviation == TemperatureGradientUnits.DegreeFahrenheitPerFoot:
            return """∆°F/ft"""
        
        if unit_abbreviation == TemperatureGradientUnits.DegreeCelsiusPerKilometer:
            return """∆°C/km"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for +: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return TemperatureGradient(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for *: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return TemperatureGradient(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for -: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return TemperatureGradient(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for /: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return TemperatureGradient(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for %: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return TemperatureGradient(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for **: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return TemperatureGradient(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for ==: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for <: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for >: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for <=: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, TemperatureGradient):
            raise TypeError("unsupported operand type(s) for >=: 'TemperatureGradient' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class AreaDensityUnits(Enum):
        """
            AreaDensityUnits enumeration
        """
        
        KilogramPerSquareMeter = 'kilogram_per_square_meter'
        """
            
        """
        
        GramPerSquareMeter = 'gram_per_square_meter'
        """
            Also known as grammage for paper industry. In fiber industry used with abbreviation 'gsm'.
        """
        
        MilligramPerSquareMeter = 'milligram_per_square_meter'
        """
            
        """
        

class AreaDensity:
    """
    The area density of a two-dimensional object is calculated as the mass per unit area. For paper this is also called grammage.

    Args:
        value (float): The value.
        from_unit (AreaDensityUnits): The AreaDensity unit to create from, The default unit is KilogramPerSquareMeter
    """
    def __init__(self, value: float, from_unit: AreaDensityUnits = AreaDensityUnits.KilogramPerSquareMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__kilograms_per_square_meter = None
        
        self.__grams_per_square_meter = None
        
        self.__milligrams_per_square_meter = None
        

    def __convert_from_base(self, from_unit: AreaDensityUnits) -> float:
        value = self.__value
        
        if from_unit == AreaDensityUnits.KilogramPerSquareMeter:
            return (value)
        
        if from_unit == AreaDensityUnits.GramPerSquareMeter:
            return (value * 1000)
        
        if from_unit == AreaDensityUnits.MilligramPerSquareMeter:
            return (value * 1000000)
        
        return None


    def __convert_to_base(self, value: float, to_unit: AreaDensityUnits) -> float:
        
        if to_unit == AreaDensityUnits.KilogramPerSquareMeter:
            return (value)
        
        if to_unit == AreaDensityUnits.GramPerSquareMeter:
            return (value / 1000)
        
        if to_unit == AreaDensityUnits.MilligramPerSquareMeter:
            return (value / 1000000)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_kilograms_per_square_meter(kilograms_per_square_meter: float):
        """
        Create a new instance of AreaDensity from a value in kilograms_per_square_meter.

        

        :param meters: The AreaDensity value in kilograms_per_square_meter.
        :type kilograms_per_square_meter: float
        :return: A new instance of AreaDensity.
        :rtype: AreaDensity
        """
        return AreaDensity(kilograms_per_square_meter, AreaDensityUnits.KilogramPerSquareMeter)

    
    @staticmethod
    def from_grams_per_square_meter(grams_per_square_meter: float):
        """
        Create a new instance of AreaDensity from a value in grams_per_square_meter.

        Also known as grammage for paper industry. In fiber industry used with abbreviation 'gsm'.

        :param meters: The AreaDensity value in grams_per_square_meter.
        :type grams_per_square_meter: float
        :return: A new instance of AreaDensity.
        :rtype: AreaDensity
        """
        return AreaDensity(grams_per_square_meter, AreaDensityUnits.GramPerSquareMeter)

    
    @staticmethod
    def from_milligrams_per_square_meter(milligrams_per_square_meter: float):
        """
        Create a new instance of AreaDensity from a value in milligrams_per_square_meter.

        

        :param meters: The AreaDensity value in milligrams_per_square_meter.
        :type milligrams_per_square_meter: float
        :return: A new instance of AreaDensity.
        :rtype: AreaDensity
        """
        return AreaDensity(milligrams_per_square_meter, AreaDensityUnits.MilligramPerSquareMeter)

    
    @property
    def kilograms_per_square_meter(self) -> float:
        """
        
        """
        if self.__kilograms_per_square_meter != None:
            return self.__kilograms_per_square_meter
        self.__kilograms_per_square_meter = self.__convert_from_base(AreaDensityUnits.KilogramPerSquareMeter)
        return self.__kilograms_per_square_meter

    
    @property
    def grams_per_square_meter(self) -> float:
        """
        Also known as grammage for paper industry. In fiber industry used with abbreviation 'gsm'.
        """
        if self.__grams_per_square_meter != None:
            return self.__grams_per_square_meter
        self.__grams_per_square_meter = self.__convert_from_base(AreaDensityUnits.GramPerSquareMeter)
        return self.__grams_per_square_meter

    
    @property
    def milligrams_per_square_meter(self) -> float:
        """
        
        """
        if self.__milligrams_per_square_meter != None:
            return self.__milligrams_per_square_meter
        self.__milligrams_per_square_meter = self.__convert_from_base(AreaDensityUnits.MilligramPerSquareMeter)
        return self.__milligrams_per_square_meter

    
    def to_string(self, unit: AreaDensityUnits = AreaDensityUnits.KilogramPerSquareMeter) -> string:
        """
        Format the AreaDensity to string.
        Note! the default format for AreaDensity is KilogramPerSquareMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == AreaDensityUnits.KilogramPerSquareMeter:
            return f"""{self.kilograms_per_square_meter} kg/m²"""
        
        if unit == AreaDensityUnits.GramPerSquareMeter:
            return f"""{self.grams_per_square_meter} g/m²"""
        
        if unit == AreaDensityUnits.MilligramPerSquareMeter:
            return f"""{self.milligrams_per_square_meter} mg/m²"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: AreaDensityUnits = AreaDensityUnits.KilogramPerSquareMeter) -> string:
        """
        Get AreaDensity unit abbreviation.
        Note! the default abbreviation for AreaDensity is KilogramPerSquareMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == AreaDensityUnits.KilogramPerSquareMeter:
            return """kg/m²"""
        
        if unit_abbreviation == AreaDensityUnits.GramPerSquareMeter:
            return """g/m²"""
        
        if unit_abbreviation == AreaDensityUnits.MilligramPerSquareMeter:
            return """mg/m²"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for +: 'AreaDensity' and '{}'".format(type(other).__name__))
        return AreaDensity(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for *: 'AreaDensity' and '{}'".format(type(other).__name__))
        return AreaDensity(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for -: 'AreaDensity' and '{}'".format(type(other).__name__))
        return AreaDensity(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for /: 'AreaDensity' and '{}'".format(type(other).__name__))
        return AreaDensity(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for %: 'AreaDensity' and '{}'".format(type(other).__name__))
        return AreaDensity(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for **: 'AreaDensity' and '{}'".format(type(other).__name__))
        return AreaDensity(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for ==: 'AreaDensity' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for <: 'AreaDensity' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for >: 'AreaDensity' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for <=: 'AreaDensity' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, AreaDensity):
            raise TypeError("unsupported operand type(s) for >=: 'AreaDensity' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class AmountOfSubstanceUnits(Enum):
        """
            AmountOfSubstanceUnits enumeration
        """
        
        Mole = 'mole'
        """
            
        """
        
        PoundMole = 'pound_mole'
        """
            
        """
        
        Femtomole = 'femtomole'
        """
            
        """
        
        Picomole = 'picomole'
        """
            
        """
        
        Nanomole = 'nanomole'
        """
            
        """
        
        Micromole = 'micromole'
        """
            
        """
        
        Millimole = 'millimole'
        """
            
        """
        
        Centimole = 'centimole'
        """
            
        """
        
        Decimole = 'decimole'
        """
            
        """
        
        Kilomole = 'kilomole'
        """
            
        """
        
        Megamole = 'megamole'
        """
            
        """
        
        NanopoundMole = 'nanopound_mole'
        """
            
        """
        
        MicropoundMole = 'micropound_mole'
        """
            
        """
        
        MillipoundMole = 'millipound_mole'
        """
            
        """
        
        CentipoundMole = 'centipound_mole'
        """
            
        """
        
        DecipoundMole = 'decipound_mole'
        """
            
        """
        
        KilopoundMole = 'kilopound_mole'
        """
            
        """
        

class AmountOfSubstance:
    """
    Mole is the amount of substance containing Avagadro's Number (6.02 x 10 ^ 23) of real particles such as molecules,atoms, ions or radicals.

    Args:
        value (float): The value.
        from_unit (AmountOfSubstanceUnits): The AmountOfSubstance unit to create from, The default unit is Mole
    """
    def __init__(self, value: float, from_unit: AmountOfSubstanceUnits = AmountOfSubstanceUnits.Mole):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__moles = None
        
        self.__pound_moles = None
        
        self.__femtomoles = None
        
        self.__picomoles = None
        
        self.__nanomoles = None
        
        self.__micromoles = None
        
        self.__millimoles = None
        
        self.__centimoles = None
        
        self.__decimoles = None
        
        self.__kilomoles = None
        
        self.__megamoles = None
        
        self.__nanopound_moles = None
        
        self.__micropound_moles = None
        
        self.__millipound_moles = None
        
        self.__centipound_moles = None
        
        self.__decipound_moles = None
        
        self.__kilopound_moles = None
        

    def __convert_from_base(self, from_unit: AmountOfSubstanceUnits) -> float:
        value = self.__value
        
        if from_unit == AmountOfSubstanceUnits.Mole:
            return (value)
        
        if from_unit == AmountOfSubstanceUnits.PoundMole:
            return (value / 453.59237)
        
        if from_unit == AmountOfSubstanceUnits.Femtomole:
            return ((value) / 1e-15)
        
        if from_unit == AmountOfSubstanceUnits.Picomole:
            return ((value) / 1e-12)
        
        if from_unit == AmountOfSubstanceUnits.Nanomole:
            return ((value) / 1e-09)
        
        if from_unit == AmountOfSubstanceUnits.Micromole:
            return ((value) / 1e-06)
        
        if from_unit == AmountOfSubstanceUnits.Millimole:
            return ((value) / 0.001)
        
        if from_unit == AmountOfSubstanceUnits.Centimole:
            return ((value) / 0.01)
        
        if from_unit == AmountOfSubstanceUnits.Decimole:
            return ((value) / 0.1)
        
        if from_unit == AmountOfSubstanceUnits.Kilomole:
            return ((value) / 1000.0)
        
        if from_unit == AmountOfSubstanceUnits.Megamole:
            return ((value) / 1000000.0)
        
        if from_unit == AmountOfSubstanceUnits.NanopoundMole:
            return ((value / 453.59237) / 1e-09)
        
        if from_unit == AmountOfSubstanceUnits.MicropoundMole:
            return ((value / 453.59237) / 1e-06)
        
        if from_unit == AmountOfSubstanceUnits.MillipoundMole:
            return ((value / 453.59237) / 0.001)
        
        if from_unit == AmountOfSubstanceUnits.CentipoundMole:
            return ((value / 453.59237) / 0.01)
        
        if from_unit == AmountOfSubstanceUnits.DecipoundMole:
            return ((value / 453.59237) / 0.1)
        
        if from_unit == AmountOfSubstanceUnits.KilopoundMole:
            return ((value / 453.59237) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: AmountOfSubstanceUnits) -> float:
        
        if to_unit == AmountOfSubstanceUnits.Mole:
            return (value)
        
        if to_unit == AmountOfSubstanceUnits.PoundMole:
            return (value * 453.59237)
        
        if to_unit == AmountOfSubstanceUnits.Femtomole:
            return ((value) * 1e-15)
        
        if to_unit == AmountOfSubstanceUnits.Picomole:
            return ((value) * 1e-12)
        
        if to_unit == AmountOfSubstanceUnits.Nanomole:
            return ((value) * 1e-09)
        
        if to_unit == AmountOfSubstanceUnits.Micromole:
            return ((value) * 1e-06)
        
        if to_unit == AmountOfSubstanceUnits.Millimole:
            return ((value) * 0.001)
        
        if to_unit == AmountOfSubstanceUnits.Centimole:
            return ((value) * 0.01)
        
        if to_unit == AmountOfSubstanceUnits.Decimole:
            return ((value) * 0.1)
        
        if to_unit == AmountOfSubstanceUnits.Kilomole:
            return ((value) * 1000.0)
        
        if to_unit == AmountOfSubstanceUnits.Megamole:
            return ((value) * 1000000.0)
        
        if to_unit == AmountOfSubstanceUnits.NanopoundMole:
            return ((value * 453.59237) * 1e-09)
        
        if to_unit == AmountOfSubstanceUnits.MicropoundMole:
            return ((value * 453.59237) * 1e-06)
        
        if to_unit == AmountOfSubstanceUnits.MillipoundMole:
            return ((value * 453.59237) * 0.001)
        
        if to_unit == AmountOfSubstanceUnits.CentipoundMole:
            return ((value * 453.59237) * 0.01)
        
        if to_unit == AmountOfSubstanceUnits.DecipoundMole:
            return ((value * 453.59237) * 0.1)
        
        if to_unit == AmountOfSubstanceUnits.KilopoundMole:
            return ((value * 453.59237) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_moles(moles: float):
        """
        Create a new instance of AmountOfSubstance from a value in moles.

        

        :param meters: The AmountOfSubstance value in moles.
        :type moles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(moles, AmountOfSubstanceUnits.Mole)

    
    @staticmethod
    def from_pound_moles(pound_moles: float):
        """
        Create a new instance of AmountOfSubstance from a value in pound_moles.

        

        :param meters: The AmountOfSubstance value in pound_moles.
        :type pound_moles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(pound_moles, AmountOfSubstanceUnits.PoundMole)

    
    @staticmethod
    def from_femtomoles(femtomoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in femtomoles.

        

        :param meters: The AmountOfSubstance value in femtomoles.
        :type femtomoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(femtomoles, AmountOfSubstanceUnits.Femtomole)

    
    @staticmethod
    def from_picomoles(picomoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in picomoles.

        

        :param meters: The AmountOfSubstance value in picomoles.
        :type picomoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(picomoles, AmountOfSubstanceUnits.Picomole)

    
    @staticmethod
    def from_nanomoles(nanomoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in nanomoles.

        

        :param meters: The AmountOfSubstance value in nanomoles.
        :type nanomoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(nanomoles, AmountOfSubstanceUnits.Nanomole)

    
    @staticmethod
    def from_micromoles(micromoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in micromoles.

        

        :param meters: The AmountOfSubstance value in micromoles.
        :type micromoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(micromoles, AmountOfSubstanceUnits.Micromole)

    
    @staticmethod
    def from_millimoles(millimoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in millimoles.

        

        :param meters: The AmountOfSubstance value in millimoles.
        :type millimoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(millimoles, AmountOfSubstanceUnits.Millimole)

    
    @staticmethod
    def from_centimoles(centimoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in centimoles.

        

        :param meters: The AmountOfSubstance value in centimoles.
        :type centimoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(centimoles, AmountOfSubstanceUnits.Centimole)

    
    @staticmethod
    def from_decimoles(decimoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in decimoles.

        

        :param meters: The AmountOfSubstance value in decimoles.
        :type decimoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(decimoles, AmountOfSubstanceUnits.Decimole)

    
    @staticmethod
    def from_kilomoles(kilomoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in kilomoles.

        

        :param meters: The AmountOfSubstance value in kilomoles.
        :type kilomoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(kilomoles, AmountOfSubstanceUnits.Kilomole)

    
    @staticmethod
    def from_megamoles(megamoles: float):
        """
        Create a new instance of AmountOfSubstance from a value in megamoles.

        

        :param meters: The AmountOfSubstance value in megamoles.
        :type megamoles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(megamoles, AmountOfSubstanceUnits.Megamole)

    
    @staticmethod
    def from_nanopound_moles(nanopound_moles: float):
        """
        Create a new instance of AmountOfSubstance from a value in nanopound_moles.

        

        :param meters: The AmountOfSubstance value in nanopound_moles.
        :type nanopound_moles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(nanopound_moles, AmountOfSubstanceUnits.NanopoundMole)

    
    @staticmethod
    def from_micropound_moles(micropound_moles: float):
        """
        Create a new instance of AmountOfSubstance from a value in micropound_moles.

        

        :param meters: The AmountOfSubstance value in micropound_moles.
        :type micropound_moles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(micropound_moles, AmountOfSubstanceUnits.MicropoundMole)

    
    @staticmethod
    def from_millipound_moles(millipound_moles: float):
        """
        Create a new instance of AmountOfSubstance from a value in millipound_moles.

        

        :param meters: The AmountOfSubstance value in millipound_moles.
        :type millipound_moles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(millipound_moles, AmountOfSubstanceUnits.MillipoundMole)

    
    @staticmethod
    def from_centipound_moles(centipound_moles: float):
        """
        Create a new instance of AmountOfSubstance from a value in centipound_moles.

        

        :param meters: The AmountOfSubstance value in centipound_moles.
        :type centipound_moles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(centipound_moles, AmountOfSubstanceUnits.CentipoundMole)

    
    @staticmethod
    def from_decipound_moles(decipound_moles: float):
        """
        Create a new instance of AmountOfSubstance from a value in decipound_moles.

        

        :param meters: The AmountOfSubstance value in decipound_moles.
        :type decipound_moles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(decipound_moles, AmountOfSubstanceUnits.DecipoundMole)

    
    @staticmethod
    def from_kilopound_moles(kilopound_moles: float):
        """
        Create a new instance of AmountOfSubstance from a value in kilopound_moles.

        

        :param meters: The AmountOfSubstance value in kilopound_moles.
        :type kilopound_moles: float
        :return: A new instance of AmountOfSubstance.
        :rtype: AmountOfSubstance
        """
        return AmountOfSubstance(kilopound_moles, AmountOfSubstanceUnits.KilopoundMole)

    
    @property
    def moles(self) -> float:
        """
        
        """
        if self.__moles != None:
            return self.__moles
        self.__moles = self.__convert_from_base(AmountOfSubstanceUnits.Mole)
        return self.__moles

    
    @property
    def pound_moles(self) -> float:
        """
        
        """
        if self.__pound_moles != None:
            return self.__pound_moles
        self.__pound_moles = self.__convert_from_base(AmountOfSubstanceUnits.PoundMole)
        return self.__pound_moles

    
    @property
    def femtomoles(self) -> float:
        """
        
        """
        if self.__femtomoles != None:
            return self.__femtomoles
        self.__femtomoles = self.__convert_from_base(AmountOfSubstanceUnits.Femtomole)
        return self.__femtomoles

    
    @property
    def picomoles(self) -> float:
        """
        
        """
        if self.__picomoles != None:
            return self.__picomoles
        self.__picomoles = self.__convert_from_base(AmountOfSubstanceUnits.Picomole)
        return self.__picomoles

    
    @property
    def nanomoles(self) -> float:
        """
        
        """
        if self.__nanomoles != None:
            return self.__nanomoles
        self.__nanomoles = self.__convert_from_base(AmountOfSubstanceUnits.Nanomole)
        return self.__nanomoles

    
    @property
    def micromoles(self) -> float:
        """
        
        """
        if self.__micromoles != None:
            return self.__micromoles
        self.__micromoles = self.__convert_from_base(AmountOfSubstanceUnits.Micromole)
        return self.__micromoles

    
    @property
    def millimoles(self) -> float:
        """
        
        """
        if self.__millimoles != None:
            return self.__millimoles
        self.__millimoles = self.__convert_from_base(AmountOfSubstanceUnits.Millimole)
        return self.__millimoles

    
    @property
    def centimoles(self) -> float:
        """
        
        """
        if self.__centimoles != None:
            return self.__centimoles
        self.__centimoles = self.__convert_from_base(AmountOfSubstanceUnits.Centimole)
        return self.__centimoles

    
    @property
    def decimoles(self) -> float:
        """
        
        """
        if self.__decimoles != None:
            return self.__decimoles
        self.__decimoles = self.__convert_from_base(AmountOfSubstanceUnits.Decimole)
        return self.__decimoles

    
    @property
    def kilomoles(self) -> float:
        """
        
        """
        if self.__kilomoles != None:
            return self.__kilomoles
        self.__kilomoles = self.__convert_from_base(AmountOfSubstanceUnits.Kilomole)
        return self.__kilomoles

    
    @property
    def megamoles(self) -> float:
        """
        
        """
        if self.__megamoles != None:
            return self.__megamoles
        self.__megamoles = self.__convert_from_base(AmountOfSubstanceUnits.Megamole)
        return self.__megamoles

    
    @property
    def nanopound_moles(self) -> float:
        """
        
        """
        if self.__nanopound_moles != None:
            return self.__nanopound_moles
        self.__nanopound_moles = self.__convert_from_base(AmountOfSubstanceUnits.NanopoundMole)
        return self.__nanopound_moles

    
    @property
    def micropound_moles(self) -> float:
        """
        
        """
        if self.__micropound_moles != None:
            return self.__micropound_moles
        self.__micropound_moles = self.__convert_from_base(AmountOfSubstanceUnits.MicropoundMole)
        return self.__micropound_moles

    
    @property
    def millipound_moles(self) -> float:
        """
        
        """
        if self.__millipound_moles != None:
            return self.__millipound_moles
        self.__millipound_moles = self.__convert_from_base(AmountOfSubstanceUnits.MillipoundMole)
        return self.__millipound_moles

    
    @property
    def centipound_moles(self) -> float:
        """
        
        """
        if self.__centipound_moles != None:
            return self.__centipound_moles
        self.__centipound_moles = self.__convert_from_base(AmountOfSubstanceUnits.CentipoundMole)
        return self.__centipound_moles

    
    @property
    def decipound_moles(self) -> float:
        """
        
        """
        if self.__decipound_moles != None:
            return self.__decipound_moles
        self.__decipound_moles = self.__convert_from_base(AmountOfSubstanceUnits.DecipoundMole)
        return self.__decipound_moles

    
    @property
    def kilopound_moles(self) -> float:
        """
        
        """
        if self.__kilopound_moles != None:
            return self.__kilopound_moles
        self.__kilopound_moles = self.__convert_from_base(AmountOfSubstanceUnits.KilopoundMole)
        return self.__kilopound_moles

    
    def to_string(self, unit: AmountOfSubstanceUnits = AmountOfSubstanceUnits.Mole) -> string:
        """
        Format the AmountOfSubstance to string.
        Note! the default format for AmountOfSubstance is Mole.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == AmountOfSubstanceUnits.Mole:
            return f"""{self.moles} mol"""
        
        if unit == AmountOfSubstanceUnits.PoundMole:
            return f"""{self.pound_moles} lbmol"""
        
        if unit == AmountOfSubstanceUnits.Femtomole:
            return f"""{self.femtomoles} """
        
        if unit == AmountOfSubstanceUnits.Picomole:
            return f"""{self.picomoles} """
        
        if unit == AmountOfSubstanceUnits.Nanomole:
            return f"""{self.nanomoles} """
        
        if unit == AmountOfSubstanceUnits.Micromole:
            return f"""{self.micromoles} """
        
        if unit == AmountOfSubstanceUnits.Millimole:
            return f"""{self.millimoles} """
        
        if unit == AmountOfSubstanceUnits.Centimole:
            return f"""{self.centimoles} """
        
        if unit == AmountOfSubstanceUnits.Decimole:
            return f"""{self.decimoles} """
        
        if unit == AmountOfSubstanceUnits.Kilomole:
            return f"""{self.kilomoles} """
        
        if unit == AmountOfSubstanceUnits.Megamole:
            return f"""{self.megamoles} """
        
        if unit == AmountOfSubstanceUnits.NanopoundMole:
            return f"""{self.nanopound_moles} """
        
        if unit == AmountOfSubstanceUnits.MicropoundMole:
            return f"""{self.micropound_moles} """
        
        if unit == AmountOfSubstanceUnits.MillipoundMole:
            return f"""{self.millipound_moles} """
        
        if unit == AmountOfSubstanceUnits.CentipoundMole:
            return f"""{self.centipound_moles} """
        
        if unit == AmountOfSubstanceUnits.DecipoundMole:
            return f"""{self.decipound_moles} """
        
        if unit == AmountOfSubstanceUnits.KilopoundMole:
            return f"""{self.kilopound_moles} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: AmountOfSubstanceUnits = AmountOfSubstanceUnits.Mole) -> string:
        """
        Get AmountOfSubstance unit abbreviation.
        Note! the default abbreviation for AmountOfSubstance is Mole.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == AmountOfSubstanceUnits.Mole:
            return """mol"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.PoundMole:
            return """lbmol"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Femtomole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Picomole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Nanomole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Micromole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Millimole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Centimole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Decimole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Kilomole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.Megamole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.NanopoundMole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.MicropoundMole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.MillipoundMole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.CentipoundMole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.DecipoundMole:
            return """"""
        
        if unit_abbreviation == AmountOfSubstanceUnits.KilopoundMole:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for +: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return AmountOfSubstance(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for *: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return AmountOfSubstance(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for -: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return AmountOfSubstance(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for /: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return AmountOfSubstance(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for %: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return AmountOfSubstance(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for **: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return AmountOfSubstance(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for ==: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for <: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for >: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for <=: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, AmountOfSubstance):
            raise TypeError("unsupported operand type(s) for >=: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class LevelUnits(Enum):
        """
            LevelUnits enumeration
        """
        
        Decibel = 'decibel'
        """
            
        """
        
        Neper = 'neper'
        """
            
        """
        

class Level:
    """
    Level is the logarithm of the ratio of a quantity Q to a reference value of that quantity, Q₀, expressed in dimensionless units.

    Args:
        value (float): The value.
        from_unit (LevelUnits): The Level unit to create from, The default unit is Decibel
    """
    def __init__(self, value: float, from_unit: LevelUnits = LevelUnits.Decibel):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__decibels = None
        
        self.__nepers = None
        

    def __convert_from_base(self, from_unit: LevelUnits) -> float:
        value = self.__value
        
        if from_unit == LevelUnits.Decibel:
            return (value)
        
        if from_unit == LevelUnits.Neper:
            return (0.115129254 * value)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LevelUnits) -> float:
        
        if to_unit == LevelUnits.Decibel:
            return (value)
        
        if to_unit == LevelUnits.Neper:
            return ((1 / 0.115129254) * value)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_decibels(decibels: float):
        """
        Create a new instance of Level from a value in decibels.

        

        :param meters: The Level value in decibels.
        :type decibels: float
        :return: A new instance of Level.
        :rtype: Level
        """
        return Level(decibels, LevelUnits.Decibel)

    
    @staticmethod
    def from_nepers(nepers: float):
        """
        Create a new instance of Level from a value in nepers.

        

        :param meters: The Level value in nepers.
        :type nepers: float
        :return: A new instance of Level.
        :rtype: Level
        """
        return Level(nepers, LevelUnits.Neper)

    
    @property
    def decibels(self) -> float:
        """
        
        """
        if self.__decibels != None:
            return self.__decibels
        self.__decibels = self.__convert_from_base(LevelUnits.Decibel)
        return self.__decibels

    
    @property
    def nepers(self) -> float:
        """
        
        """
        if self.__nepers != None:
            return self.__nepers
        self.__nepers = self.__convert_from_base(LevelUnits.Neper)
        return self.__nepers

    
    def to_string(self, unit: LevelUnits = LevelUnits.Decibel) -> string:
        """
        Format the Level to string.
        Note! the default format for Level is Decibel.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == LevelUnits.Decibel:
            return f"""{self.decibels} dB"""
        
        if unit == LevelUnits.Neper:
            return f"""{self.nepers} Np"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: LevelUnits = LevelUnits.Decibel) -> string:
        """
        Get Level unit abbreviation.
        Note! the default abbreviation for Level is Decibel.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LevelUnits.Decibel:
            return """dB"""
        
        if unit_abbreviation == LevelUnits.Neper:
            return """Np"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for +: 'Level' and '{}'".format(type(other).__name__))
        return Level(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for *: 'Level' and '{}'".format(type(other).__name__))
        return Level(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for -: 'Level' and '{}'".format(type(other).__name__))
        return Level(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for /: 'Level' and '{}'".format(type(other).__name__))
        return Level(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for %: 'Level' and '{}'".format(type(other).__name__))
        return Level(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for **: 'Level' and '{}'".format(type(other).__name__))
        return Level(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for ==: 'Level' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for <: 'Level' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for >: 'Level' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for <=: 'Level' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Level):
            raise TypeError("unsupported operand type(s) for >=: 'Level' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ForceChangeRateUnits(Enum):
        """
            ForceChangeRateUnits enumeration
        """
        
        NewtonPerMinute = 'newton_per_minute'
        """
            
        """
        
        NewtonPerSecond = 'newton_per_second'
        """
            
        """
        
        PoundForcePerMinute = 'pound_force_per_minute'
        """
            
        """
        
        PoundForcePerSecond = 'pound_force_per_second'
        """
            
        """
        
        DecanewtonPerMinute = 'decanewton_per_minute'
        """
            
        """
        
        KilonewtonPerMinute = 'kilonewton_per_minute'
        """
            
        """
        
        NanonewtonPerSecond = 'nanonewton_per_second'
        """
            
        """
        
        MicronewtonPerSecond = 'micronewton_per_second'
        """
            
        """
        
        MillinewtonPerSecond = 'millinewton_per_second'
        """
            
        """
        
        CentinewtonPerSecond = 'centinewton_per_second'
        """
            
        """
        
        DecinewtonPerSecond = 'decinewton_per_second'
        """
            
        """
        
        DecanewtonPerSecond = 'decanewton_per_second'
        """
            
        """
        
        KilonewtonPerSecond = 'kilonewton_per_second'
        """
            
        """
        
        KilopoundForcePerMinute = 'kilopound_force_per_minute'
        """
            
        """
        
        KilopoundForcePerSecond = 'kilopound_force_per_second'
        """
            
        """
        

class ForceChangeRate:
    """
    Force change rate is the ratio of the force change to the time during which the change occurred (value of force changes per unit time).

    Args:
        value (float): The value.
        from_unit (ForceChangeRateUnits): The ForceChangeRate unit to create from, The default unit is NewtonPerSecond
    """
    def __init__(self, value: float, from_unit: ForceChangeRateUnits = ForceChangeRateUnits.NewtonPerSecond):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__newtons_per_minute = None
        
        self.__newtons_per_second = None
        
        self.__pounds_force_per_minute = None
        
        self.__pounds_force_per_second = None
        
        self.__decanewtons_per_minute = None
        
        self.__kilonewtons_per_minute = None
        
        self.__nanonewtons_per_second = None
        
        self.__micronewtons_per_second = None
        
        self.__millinewtons_per_second = None
        
        self.__centinewtons_per_second = None
        
        self.__decinewtons_per_second = None
        
        self.__decanewtons_per_second = None
        
        self.__kilonewtons_per_second = None
        
        self.__kilopounds_force_per_minute = None
        
        self.__kilopounds_force_per_second = None
        

    def __convert_from_base(self, from_unit: ForceChangeRateUnits) -> float:
        value = self.__value
        
        if from_unit == ForceChangeRateUnits.NewtonPerMinute:
            return (value * 60)
        
        if from_unit == ForceChangeRateUnits.NewtonPerSecond:
            return (value)
        
        if from_unit == ForceChangeRateUnits.PoundForcePerMinute:
            return (value / 4.4482216152605095551842641431421 * 60)
        
        if from_unit == ForceChangeRateUnits.PoundForcePerSecond:
            return (value / 4.4482216152605095551842641431421)
        
        if from_unit == ForceChangeRateUnits.DecanewtonPerMinute:
            return ((value * 60) / 10.0)
        
        if from_unit == ForceChangeRateUnits.KilonewtonPerMinute:
            return ((value * 60) / 1000.0)
        
        if from_unit == ForceChangeRateUnits.NanonewtonPerSecond:
            return ((value) / 1e-09)
        
        if from_unit == ForceChangeRateUnits.MicronewtonPerSecond:
            return ((value) / 1e-06)
        
        if from_unit == ForceChangeRateUnits.MillinewtonPerSecond:
            return ((value) / 0.001)
        
        if from_unit == ForceChangeRateUnits.CentinewtonPerSecond:
            return ((value) / 0.01)
        
        if from_unit == ForceChangeRateUnits.DecinewtonPerSecond:
            return ((value) / 0.1)
        
        if from_unit == ForceChangeRateUnits.DecanewtonPerSecond:
            return ((value) / 10.0)
        
        if from_unit == ForceChangeRateUnits.KilonewtonPerSecond:
            return ((value) / 1000.0)
        
        if from_unit == ForceChangeRateUnits.KilopoundForcePerMinute:
            return ((value / 4.4482216152605095551842641431421 * 60) / 1000.0)
        
        if from_unit == ForceChangeRateUnits.KilopoundForcePerSecond:
            return ((value / 4.4482216152605095551842641431421) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ForceChangeRateUnits) -> float:
        
        if to_unit == ForceChangeRateUnits.NewtonPerMinute:
            return (value / 60)
        
        if to_unit == ForceChangeRateUnits.NewtonPerSecond:
            return (value)
        
        if to_unit == ForceChangeRateUnits.PoundForcePerMinute:
            return (value * 4.4482216152605095551842641431421 / 60)
        
        if to_unit == ForceChangeRateUnits.PoundForcePerSecond:
            return (value * 4.4482216152605095551842641431421)
        
        if to_unit == ForceChangeRateUnits.DecanewtonPerMinute:
            return ((value / 60) * 10.0)
        
        if to_unit == ForceChangeRateUnits.KilonewtonPerMinute:
            return ((value / 60) * 1000.0)
        
        if to_unit == ForceChangeRateUnits.NanonewtonPerSecond:
            return ((value) * 1e-09)
        
        if to_unit == ForceChangeRateUnits.MicronewtonPerSecond:
            return ((value) * 1e-06)
        
        if to_unit == ForceChangeRateUnits.MillinewtonPerSecond:
            return ((value) * 0.001)
        
        if to_unit == ForceChangeRateUnits.CentinewtonPerSecond:
            return ((value) * 0.01)
        
        if to_unit == ForceChangeRateUnits.DecinewtonPerSecond:
            return ((value) * 0.1)
        
        if to_unit == ForceChangeRateUnits.DecanewtonPerSecond:
            return ((value) * 10.0)
        
        if to_unit == ForceChangeRateUnits.KilonewtonPerSecond:
            return ((value) * 1000.0)
        
        if to_unit == ForceChangeRateUnits.KilopoundForcePerMinute:
            return ((value * 4.4482216152605095551842641431421 / 60) * 1000.0)
        
        if to_unit == ForceChangeRateUnits.KilopoundForcePerSecond:
            return ((value * 4.4482216152605095551842641431421) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_newtons_per_minute(newtons_per_minute: float):
        """
        Create a new instance of ForceChangeRate from a value in newtons_per_minute.

        

        :param meters: The ForceChangeRate value in newtons_per_minute.
        :type newtons_per_minute: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(newtons_per_minute, ForceChangeRateUnits.NewtonPerMinute)

    
    @staticmethod
    def from_newtons_per_second(newtons_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in newtons_per_second.

        

        :param meters: The ForceChangeRate value in newtons_per_second.
        :type newtons_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(newtons_per_second, ForceChangeRateUnits.NewtonPerSecond)

    
    @staticmethod
    def from_pounds_force_per_minute(pounds_force_per_minute: float):
        """
        Create a new instance of ForceChangeRate from a value in pounds_force_per_minute.

        

        :param meters: The ForceChangeRate value in pounds_force_per_minute.
        :type pounds_force_per_minute: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(pounds_force_per_minute, ForceChangeRateUnits.PoundForcePerMinute)

    
    @staticmethod
    def from_pounds_force_per_second(pounds_force_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in pounds_force_per_second.

        

        :param meters: The ForceChangeRate value in pounds_force_per_second.
        :type pounds_force_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(pounds_force_per_second, ForceChangeRateUnits.PoundForcePerSecond)

    
    @staticmethod
    def from_decanewtons_per_minute(decanewtons_per_minute: float):
        """
        Create a new instance of ForceChangeRate from a value in decanewtons_per_minute.

        

        :param meters: The ForceChangeRate value in decanewtons_per_minute.
        :type decanewtons_per_minute: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(decanewtons_per_minute, ForceChangeRateUnits.DecanewtonPerMinute)

    
    @staticmethod
    def from_kilonewtons_per_minute(kilonewtons_per_minute: float):
        """
        Create a new instance of ForceChangeRate from a value in kilonewtons_per_minute.

        

        :param meters: The ForceChangeRate value in kilonewtons_per_minute.
        :type kilonewtons_per_minute: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(kilonewtons_per_minute, ForceChangeRateUnits.KilonewtonPerMinute)

    
    @staticmethod
    def from_nanonewtons_per_second(nanonewtons_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in nanonewtons_per_second.

        

        :param meters: The ForceChangeRate value in nanonewtons_per_second.
        :type nanonewtons_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(nanonewtons_per_second, ForceChangeRateUnits.NanonewtonPerSecond)

    
    @staticmethod
    def from_micronewtons_per_second(micronewtons_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in micronewtons_per_second.

        

        :param meters: The ForceChangeRate value in micronewtons_per_second.
        :type micronewtons_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(micronewtons_per_second, ForceChangeRateUnits.MicronewtonPerSecond)

    
    @staticmethod
    def from_millinewtons_per_second(millinewtons_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in millinewtons_per_second.

        

        :param meters: The ForceChangeRate value in millinewtons_per_second.
        :type millinewtons_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(millinewtons_per_second, ForceChangeRateUnits.MillinewtonPerSecond)

    
    @staticmethod
    def from_centinewtons_per_second(centinewtons_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in centinewtons_per_second.

        

        :param meters: The ForceChangeRate value in centinewtons_per_second.
        :type centinewtons_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(centinewtons_per_second, ForceChangeRateUnits.CentinewtonPerSecond)

    
    @staticmethod
    def from_decinewtons_per_second(decinewtons_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in decinewtons_per_second.

        

        :param meters: The ForceChangeRate value in decinewtons_per_second.
        :type decinewtons_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(decinewtons_per_second, ForceChangeRateUnits.DecinewtonPerSecond)

    
    @staticmethod
    def from_decanewtons_per_second(decanewtons_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in decanewtons_per_second.

        

        :param meters: The ForceChangeRate value in decanewtons_per_second.
        :type decanewtons_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(decanewtons_per_second, ForceChangeRateUnits.DecanewtonPerSecond)

    
    @staticmethod
    def from_kilonewtons_per_second(kilonewtons_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in kilonewtons_per_second.

        

        :param meters: The ForceChangeRate value in kilonewtons_per_second.
        :type kilonewtons_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(kilonewtons_per_second, ForceChangeRateUnits.KilonewtonPerSecond)

    
    @staticmethod
    def from_kilopounds_force_per_minute(kilopounds_force_per_minute: float):
        """
        Create a new instance of ForceChangeRate from a value in kilopounds_force_per_minute.

        

        :param meters: The ForceChangeRate value in kilopounds_force_per_minute.
        :type kilopounds_force_per_minute: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(kilopounds_force_per_minute, ForceChangeRateUnits.KilopoundForcePerMinute)

    
    @staticmethod
    def from_kilopounds_force_per_second(kilopounds_force_per_second: float):
        """
        Create a new instance of ForceChangeRate from a value in kilopounds_force_per_second.

        

        :param meters: The ForceChangeRate value in kilopounds_force_per_second.
        :type kilopounds_force_per_second: float
        :return: A new instance of ForceChangeRate.
        :rtype: ForceChangeRate
        """
        return ForceChangeRate(kilopounds_force_per_second, ForceChangeRateUnits.KilopoundForcePerSecond)

    
    @property
    def newtons_per_minute(self) -> float:
        """
        
        """
        if self.__newtons_per_minute != None:
            return self.__newtons_per_minute
        self.__newtons_per_minute = self.__convert_from_base(ForceChangeRateUnits.NewtonPerMinute)
        return self.__newtons_per_minute

    
    @property
    def newtons_per_second(self) -> float:
        """
        
        """
        if self.__newtons_per_second != None:
            return self.__newtons_per_second
        self.__newtons_per_second = self.__convert_from_base(ForceChangeRateUnits.NewtonPerSecond)
        return self.__newtons_per_second

    
    @property
    def pounds_force_per_minute(self) -> float:
        """
        
        """
        if self.__pounds_force_per_minute != None:
            return self.__pounds_force_per_minute
        self.__pounds_force_per_minute = self.__convert_from_base(ForceChangeRateUnits.PoundForcePerMinute)
        return self.__pounds_force_per_minute

    
    @property
    def pounds_force_per_second(self) -> float:
        """
        
        """
        if self.__pounds_force_per_second != None:
            return self.__pounds_force_per_second
        self.__pounds_force_per_second = self.__convert_from_base(ForceChangeRateUnits.PoundForcePerSecond)
        return self.__pounds_force_per_second

    
    @property
    def decanewtons_per_minute(self) -> float:
        """
        
        """
        if self.__decanewtons_per_minute != None:
            return self.__decanewtons_per_minute
        self.__decanewtons_per_minute = self.__convert_from_base(ForceChangeRateUnits.DecanewtonPerMinute)
        return self.__decanewtons_per_minute

    
    @property
    def kilonewtons_per_minute(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_minute != None:
            return self.__kilonewtons_per_minute
        self.__kilonewtons_per_minute = self.__convert_from_base(ForceChangeRateUnits.KilonewtonPerMinute)
        return self.__kilonewtons_per_minute

    
    @property
    def nanonewtons_per_second(self) -> float:
        """
        
        """
        if self.__nanonewtons_per_second != None:
            return self.__nanonewtons_per_second
        self.__nanonewtons_per_second = self.__convert_from_base(ForceChangeRateUnits.NanonewtonPerSecond)
        return self.__nanonewtons_per_second

    
    @property
    def micronewtons_per_second(self) -> float:
        """
        
        """
        if self.__micronewtons_per_second != None:
            return self.__micronewtons_per_second
        self.__micronewtons_per_second = self.__convert_from_base(ForceChangeRateUnits.MicronewtonPerSecond)
        return self.__micronewtons_per_second

    
    @property
    def millinewtons_per_second(self) -> float:
        """
        
        """
        if self.__millinewtons_per_second != None:
            return self.__millinewtons_per_second
        self.__millinewtons_per_second = self.__convert_from_base(ForceChangeRateUnits.MillinewtonPerSecond)
        return self.__millinewtons_per_second

    
    @property
    def centinewtons_per_second(self) -> float:
        """
        
        """
        if self.__centinewtons_per_second != None:
            return self.__centinewtons_per_second
        self.__centinewtons_per_second = self.__convert_from_base(ForceChangeRateUnits.CentinewtonPerSecond)
        return self.__centinewtons_per_second

    
    @property
    def decinewtons_per_second(self) -> float:
        """
        
        """
        if self.__decinewtons_per_second != None:
            return self.__decinewtons_per_second
        self.__decinewtons_per_second = self.__convert_from_base(ForceChangeRateUnits.DecinewtonPerSecond)
        return self.__decinewtons_per_second

    
    @property
    def decanewtons_per_second(self) -> float:
        """
        
        """
        if self.__decanewtons_per_second != None:
            return self.__decanewtons_per_second
        self.__decanewtons_per_second = self.__convert_from_base(ForceChangeRateUnits.DecanewtonPerSecond)
        return self.__decanewtons_per_second

    
    @property
    def kilonewtons_per_second(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_second != None:
            return self.__kilonewtons_per_second
        self.__kilonewtons_per_second = self.__convert_from_base(ForceChangeRateUnits.KilonewtonPerSecond)
        return self.__kilonewtons_per_second

    
    @property
    def kilopounds_force_per_minute(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_minute != None:
            return self.__kilopounds_force_per_minute
        self.__kilopounds_force_per_minute = self.__convert_from_base(ForceChangeRateUnits.KilopoundForcePerMinute)
        return self.__kilopounds_force_per_minute

    
    @property
    def kilopounds_force_per_second(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_second != None:
            return self.__kilopounds_force_per_second
        self.__kilopounds_force_per_second = self.__convert_from_base(ForceChangeRateUnits.KilopoundForcePerSecond)
        return self.__kilopounds_force_per_second

    
    def to_string(self, unit: ForceChangeRateUnits = ForceChangeRateUnits.NewtonPerSecond) -> string:
        """
        Format the ForceChangeRate to string.
        Note! the default format for ForceChangeRate is NewtonPerSecond.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ForceChangeRateUnits.NewtonPerMinute:
            return f"""{self.newtons_per_minute} N/min"""
        
        if unit == ForceChangeRateUnits.NewtonPerSecond:
            return f"""{self.newtons_per_second} N/s"""
        
        if unit == ForceChangeRateUnits.PoundForcePerMinute:
            return f"""{self.pounds_force_per_minute} lbf/min"""
        
        if unit == ForceChangeRateUnits.PoundForcePerSecond:
            return f"""{self.pounds_force_per_second} lbf/s"""
        
        if unit == ForceChangeRateUnits.DecanewtonPerMinute:
            return f"""{self.decanewtons_per_minute} """
        
        if unit == ForceChangeRateUnits.KilonewtonPerMinute:
            return f"""{self.kilonewtons_per_minute} """
        
        if unit == ForceChangeRateUnits.NanonewtonPerSecond:
            return f"""{self.nanonewtons_per_second} """
        
        if unit == ForceChangeRateUnits.MicronewtonPerSecond:
            return f"""{self.micronewtons_per_second} """
        
        if unit == ForceChangeRateUnits.MillinewtonPerSecond:
            return f"""{self.millinewtons_per_second} """
        
        if unit == ForceChangeRateUnits.CentinewtonPerSecond:
            return f"""{self.centinewtons_per_second} """
        
        if unit == ForceChangeRateUnits.DecinewtonPerSecond:
            return f"""{self.decinewtons_per_second} """
        
        if unit == ForceChangeRateUnits.DecanewtonPerSecond:
            return f"""{self.decanewtons_per_second} """
        
        if unit == ForceChangeRateUnits.KilonewtonPerSecond:
            return f"""{self.kilonewtons_per_second} """
        
        if unit == ForceChangeRateUnits.KilopoundForcePerMinute:
            return f"""{self.kilopounds_force_per_minute} """
        
        if unit == ForceChangeRateUnits.KilopoundForcePerSecond:
            return f"""{self.kilopounds_force_per_second} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ForceChangeRateUnits = ForceChangeRateUnits.NewtonPerSecond) -> string:
        """
        Get ForceChangeRate unit abbreviation.
        Note! the default abbreviation for ForceChangeRate is NewtonPerSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ForceChangeRateUnits.NewtonPerMinute:
            return """N/min"""
        
        if unit_abbreviation == ForceChangeRateUnits.NewtonPerSecond:
            return """N/s"""
        
        if unit_abbreviation == ForceChangeRateUnits.PoundForcePerMinute:
            return """lbf/min"""
        
        if unit_abbreviation == ForceChangeRateUnits.PoundForcePerSecond:
            return """lbf/s"""
        
        if unit_abbreviation == ForceChangeRateUnits.DecanewtonPerMinute:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.KilonewtonPerMinute:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.NanonewtonPerSecond:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.MicronewtonPerSecond:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.MillinewtonPerSecond:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.CentinewtonPerSecond:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.DecinewtonPerSecond:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.DecanewtonPerSecond:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.KilonewtonPerSecond:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.KilopoundForcePerMinute:
            return """"""
        
        if unit_abbreviation == ForceChangeRateUnits.KilopoundForcePerSecond:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for +: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return ForceChangeRate(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for *: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return ForceChangeRate(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for -: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return ForceChangeRate(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for /: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return ForceChangeRate(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for %: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return ForceChangeRate(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for **: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return ForceChangeRate(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for ==: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for <: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for >: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for <=: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ForceChangeRate):
            raise TypeError("unsupported operand type(s) for >=: 'ForceChangeRate' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ElectricConductanceUnits(Enum):
        """
            ElectricConductanceUnits enumeration
        """
        
        Siemens = 'siemens'
        """
            
        """
        
        Nanosiemens = 'nanosiemens'
        """
            
        """
        
        Microsiemens = 'microsiemens'
        """
            
        """
        
        Millisiemens = 'millisiemens'
        """
            
        """
        
        Kilosiemens = 'kilosiemens'
        """
            
        """
        

class ElectricConductance:
    """
    The electrical conductance of an electrical conductor is a measure of the easeness to pass an electric current through that conductor.

    Args:
        value (float): The value.
        from_unit (ElectricConductanceUnits): The ElectricConductance unit to create from, The default unit is Siemens
    """
    def __init__(self, value: float, from_unit: ElectricConductanceUnits = ElectricConductanceUnits.Siemens):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__siemens = None
        
        self.__nanosiemens = None
        
        self.__microsiemens = None
        
        self.__millisiemens = None
        
        self.__kilosiemens = None
        

    def __convert_from_base(self, from_unit: ElectricConductanceUnits) -> float:
        value = self.__value
        
        if from_unit == ElectricConductanceUnits.Siemens:
            return (value)
        
        if from_unit == ElectricConductanceUnits.Nanosiemens:
            return ((value) / 1e-09)
        
        if from_unit == ElectricConductanceUnits.Microsiemens:
            return ((value) / 1e-06)
        
        if from_unit == ElectricConductanceUnits.Millisiemens:
            return ((value) / 0.001)
        
        if from_unit == ElectricConductanceUnits.Kilosiemens:
            return ((value) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricConductanceUnits) -> float:
        
        if to_unit == ElectricConductanceUnits.Siemens:
            return (value)
        
        if to_unit == ElectricConductanceUnits.Nanosiemens:
            return ((value) * 1e-09)
        
        if to_unit == ElectricConductanceUnits.Microsiemens:
            return ((value) * 1e-06)
        
        if to_unit == ElectricConductanceUnits.Millisiemens:
            return ((value) * 0.001)
        
        if to_unit == ElectricConductanceUnits.Kilosiemens:
            return ((value) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_siemens(siemens: float):
        """
        Create a new instance of ElectricConductance from a value in siemens.

        

        :param meters: The ElectricConductance value in siemens.
        :type siemens: float
        :return: A new instance of ElectricConductance.
        :rtype: ElectricConductance
        """
        return ElectricConductance(siemens, ElectricConductanceUnits.Siemens)

    
    @staticmethod
    def from_nanosiemens(nanosiemens: float):
        """
        Create a new instance of ElectricConductance from a value in nanosiemens.

        

        :param meters: The ElectricConductance value in nanosiemens.
        :type nanosiemens: float
        :return: A new instance of ElectricConductance.
        :rtype: ElectricConductance
        """
        return ElectricConductance(nanosiemens, ElectricConductanceUnits.Nanosiemens)

    
    @staticmethod
    def from_microsiemens(microsiemens: float):
        """
        Create a new instance of ElectricConductance from a value in microsiemens.

        

        :param meters: The ElectricConductance value in microsiemens.
        :type microsiemens: float
        :return: A new instance of ElectricConductance.
        :rtype: ElectricConductance
        """
        return ElectricConductance(microsiemens, ElectricConductanceUnits.Microsiemens)

    
    @staticmethod
    def from_millisiemens(millisiemens: float):
        """
        Create a new instance of ElectricConductance from a value in millisiemens.

        

        :param meters: The ElectricConductance value in millisiemens.
        :type millisiemens: float
        :return: A new instance of ElectricConductance.
        :rtype: ElectricConductance
        """
        return ElectricConductance(millisiemens, ElectricConductanceUnits.Millisiemens)

    
    @staticmethod
    def from_kilosiemens(kilosiemens: float):
        """
        Create a new instance of ElectricConductance from a value in kilosiemens.

        

        :param meters: The ElectricConductance value in kilosiemens.
        :type kilosiemens: float
        :return: A new instance of ElectricConductance.
        :rtype: ElectricConductance
        """
        return ElectricConductance(kilosiemens, ElectricConductanceUnits.Kilosiemens)

    
    @property
    def siemens(self) -> float:
        """
        
        """
        if self.__siemens != None:
            return self.__siemens
        self.__siemens = self.__convert_from_base(ElectricConductanceUnits.Siemens)
        return self.__siemens

    
    @property
    def nanosiemens(self) -> float:
        """
        
        """
        if self.__nanosiemens != None:
            return self.__nanosiemens
        self.__nanosiemens = self.__convert_from_base(ElectricConductanceUnits.Nanosiemens)
        return self.__nanosiemens

    
    @property
    def microsiemens(self) -> float:
        """
        
        """
        if self.__microsiemens != None:
            return self.__microsiemens
        self.__microsiemens = self.__convert_from_base(ElectricConductanceUnits.Microsiemens)
        return self.__microsiemens

    
    @property
    def millisiemens(self) -> float:
        """
        
        """
        if self.__millisiemens != None:
            return self.__millisiemens
        self.__millisiemens = self.__convert_from_base(ElectricConductanceUnits.Millisiemens)
        return self.__millisiemens

    
    @property
    def kilosiemens(self) -> float:
        """
        
        """
        if self.__kilosiemens != None:
            return self.__kilosiemens
        self.__kilosiemens = self.__convert_from_base(ElectricConductanceUnits.Kilosiemens)
        return self.__kilosiemens

    
    def to_string(self, unit: ElectricConductanceUnits = ElectricConductanceUnits.Siemens) -> string:
        """
        Format the ElectricConductance to string.
        Note! the default format for ElectricConductance is Siemens.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ElectricConductanceUnits.Siemens:
            return f"""{self.siemens} S"""
        
        if unit == ElectricConductanceUnits.Nanosiemens:
            return f"""{self.nanosiemens} """
        
        if unit == ElectricConductanceUnits.Microsiemens:
            return f"""{self.microsiemens} """
        
        if unit == ElectricConductanceUnits.Millisiemens:
            return f"""{self.millisiemens} """
        
        if unit == ElectricConductanceUnits.Kilosiemens:
            return f"""{self.kilosiemens} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricConductanceUnits = ElectricConductanceUnits.Siemens) -> string:
        """
        Get ElectricConductance unit abbreviation.
        Note! the default abbreviation for ElectricConductance is Siemens.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricConductanceUnits.Siemens:
            return """S"""
        
        if unit_abbreviation == ElectricConductanceUnits.Nanosiemens:
            return """"""
        
        if unit_abbreviation == ElectricConductanceUnits.Microsiemens:
            return """"""
        
        if unit_abbreviation == ElectricConductanceUnits.Millisiemens:
            return """"""
        
        if unit_abbreviation == ElectricConductanceUnits.Kilosiemens:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for +: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return ElectricConductance(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for *: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return ElectricConductance(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for -: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return ElectricConductance(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for /: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return ElectricConductance(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for %: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return ElectricConductance(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for **: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return ElectricConductance(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for ==: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for <: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for >: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for <=: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ElectricConductance):
            raise TypeError("unsupported operand type(s) for >=: 'ElectricConductance' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class FuelEfficiencyUnits(Enum):
        """
            FuelEfficiencyUnits enumeration
        """
        
        LiterPer100Kilometers = 'liter_per100_kilometers'
        """
            
        """
        
        MilePerUsGallon = 'mile_per_us_gallon'
        """
            
        """
        
        MilePerUkGallon = 'mile_per_uk_gallon'
        """
            
        """
        
        KilometerPerLiter = 'kilometer_per_liter'
        """
            
        """
        

class FuelEfficiency:
    """
    Fuel efficiency is a form of thermal efficiency, meaning the ratio from effort to result of a process that converts chemical potential energy contained in a carrier (fuel) into kinetic energy or work. Fuel economy is stated as "fuel consumption" in liters per 100 kilometers (L/100 km). In countries using non-metric system, fuel economy is expressed in miles per gallon (mpg) (imperial galon or US galon).

    Args:
        value (float): The value.
        from_unit (FuelEfficiencyUnits): The FuelEfficiency unit to create from, The default unit is LiterPer100Kilometers
    """
    def __init__(self, value: float, from_unit: FuelEfficiencyUnits = FuelEfficiencyUnits.LiterPer100Kilometers):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__liters_per100_kilometers = None
        
        self.__miles_per_us_gallon = None
        
        self.__miles_per_uk_gallon = None
        
        self.__kilometers_per_liters = None
        

    def __convert_from_base(self, from_unit: FuelEfficiencyUnits) -> float:
        value = self.__value
        
        if from_unit == FuelEfficiencyUnits.LiterPer100Kilometers:
            return (value)
        
        if from_unit == FuelEfficiencyUnits.MilePerUsGallon:
            return ((100 * 3.785411784) / (1.609344 * value))
        
        if from_unit == FuelEfficiencyUnits.MilePerUkGallon:
            return ((100 * 4.54609188) / (1.609344 * value))
        
        if from_unit == FuelEfficiencyUnits.KilometerPerLiter:
            return (100 / value)
        
        return None


    def __convert_to_base(self, value: float, to_unit: FuelEfficiencyUnits) -> float:
        
        if to_unit == FuelEfficiencyUnits.LiterPer100Kilometers:
            return (value)
        
        if to_unit == FuelEfficiencyUnits.MilePerUsGallon:
            return ((100 * 3.785411784) / (1.609344 * value))
        
        if to_unit == FuelEfficiencyUnits.MilePerUkGallon:
            return ((100 * 4.54609188) / (1.609344 * value))
        
        if to_unit == FuelEfficiencyUnits.KilometerPerLiter:
            return (100 / value)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_liters_per100_kilometers(liters_per100_kilometers: float):
        """
        Create a new instance of FuelEfficiency from a value in liters_per100_kilometers.

        

        :param meters: The FuelEfficiency value in liters_per100_kilometers.
        :type liters_per100_kilometers: float
        :return: A new instance of FuelEfficiency.
        :rtype: FuelEfficiency
        """
        return FuelEfficiency(liters_per100_kilometers, FuelEfficiencyUnits.LiterPer100Kilometers)

    
    @staticmethod
    def from_miles_per_us_gallon(miles_per_us_gallon: float):
        """
        Create a new instance of FuelEfficiency from a value in miles_per_us_gallon.

        

        :param meters: The FuelEfficiency value in miles_per_us_gallon.
        :type miles_per_us_gallon: float
        :return: A new instance of FuelEfficiency.
        :rtype: FuelEfficiency
        """
        return FuelEfficiency(miles_per_us_gallon, FuelEfficiencyUnits.MilePerUsGallon)

    
    @staticmethod
    def from_miles_per_uk_gallon(miles_per_uk_gallon: float):
        """
        Create a new instance of FuelEfficiency from a value in miles_per_uk_gallon.

        

        :param meters: The FuelEfficiency value in miles_per_uk_gallon.
        :type miles_per_uk_gallon: float
        :return: A new instance of FuelEfficiency.
        :rtype: FuelEfficiency
        """
        return FuelEfficiency(miles_per_uk_gallon, FuelEfficiencyUnits.MilePerUkGallon)

    
    @staticmethod
    def from_kilometers_per_liters(kilometers_per_liters: float):
        """
        Create a new instance of FuelEfficiency from a value in kilometers_per_liters.

        

        :param meters: The FuelEfficiency value in kilometers_per_liters.
        :type kilometers_per_liters: float
        :return: A new instance of FuelEfficiency.
        :rtype: FuelEfficiency
        """
        return FuelEfficiency(kilometers_per_liters, FuelEfficiencyUnits.KilometerPerLiter)

    
    @property
    def liters_per100_kilometers(self) -> float:
        """
        
        """
        if self.__liters_per100_kilometers != None:
            return self.__liters_per100_kilometers
        self.__liters_per100_kilometers = self.__convert_from_base(FuelEfficiencyUnits.LiterPer100Kilometers)
        return self.__liters_per100_kilometers

    
    @property
    def miles_per_us_gallon(self) -> float:
        """
        
        """
        if self.__miles_per_us_gallon != None:
            return self.__miles_per_us_gallon
        self.__miles_per_us_gallon = self.__convert_from_base(FuelEfficiencyUnits.MilePerUsGallon)
        return self.__miles_per_us_gallon

    
    @property
    def miles_per_uk_gallon(self) -> float:
        """
        
        """
        if self.__miles_per_uk_gallon != None:
            return self.__miles_per_uk_gallon
        self.__miles_per_uk_gallon = self.__convert_from_base(FuelEfficiencyUnits.MilePerUkGallon)
        return self.__miles_per_uk_gallon

    
    @property
    def kilometers_per_liters(self) -> float:
        """
        
        """
        if self.__kilometers_per_liters != None:
            return self.__kilometers_per_liters
        self.__kilometers_per_liters = self.__convert_from_base(FuelEfficiencyUnits.KilometerPerLiter)
        return self.__kilometers_per_liters

    
    def to_string(self, unit: FuelEfficiencyUnits = FuelEfficiencyUnits.LiterPer100Kilometers) -> string:
        """
        Format the FuelEfficiency to string.
        Note! the default format for FuelEfficiency is LiterPer100Kilometers.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == FuelEfficiencyUnits.LiterPer100Kilometers:
            return f"""{self.liters_per100_kilometers} L/100km"""
        
        if unit == FuelEfficiencyUnits.MilePerUsGallon:
            return f"""{self.miles_per_us_gallon} mpg (U.S.)"""
        
        if unit == FuelEfficiencyUnits.MilePerUkGallon:
            return f"""{self.miles_per_uk_gallon} mpg (imp.)"""
        
        if unit == FuelEfficiencyUnits.KilometerPerLiter:
            return f"""{self.kilometers_per_liters} km/L"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: FuelEfficiencyUnits = FuelEfficiencyUnits.LiterPer100Kilometers) -> string:
        """
        Get FuelEfficiency unit abbreviation.
        Note! the default abbreviation for FuelEfficiency is LiterPer100Kilometers.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == FuelEfficiencyUnits.LiterPer100Kilometers:
            return """L/100km"""
        
        if unit_abbreviation == FuelEfficiencyUnits.MilePerUsGallon:
            return """mpg (U.S.)"""
        
        if unit_abbreviation == FuelEfficiencyUnits.MilePerUkGallon:
            return """mpg (imp.)"""
        
        if unit_abbreviation == FuelEfficiencyUnits.KilometerPerLiter:
            return """km/L"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for +: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return FuelEfficiency(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for *: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return FuelEfficiency(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for -: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return FuelEfficiency(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for /: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return FuelEfficiency(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for %: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return FuelEfficiency(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for **: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return FuelEfficiency(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for ==: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for <: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for >: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for <=: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, FuelEfficiency):
            raise TypeError("unsupported operand type(s) for >=: 'FuelEfficiency' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class LinearPowerDensityUnits(Enum):
        """
            LinearPowerDensityUnits enumeration
        """
        
        WattPerMeter = 'watt_per_meter'
        """
            
        """
        
        WattPerCentimeter = 'watt_per_centimeter'
        """
            
        """
        
        WattPerMillimeter = 'watt_per_millimeter'
        """
            
        """
        
        WattPerInch = 'watt_per_inch'
        """
            
        """
        
        WattPerFoot = 'watt_per_foot'
        """
            
        """
        
        MilliwattPerMeter = 'milliwatt_per_meter'
        """
            
        """
        
        KilowattPerMeter = 'kilowatt_per_meter'
        """
            
        """
        
        MegawattPerMeter = 'megawatt_per_meter'
        """
            
        """
        
        GigawattPerMeter = 'gigawatt_per_meter'
        """
            
        """
        
        MilliwattPerCentimeter = 'milliwatt_per_centimeter'
        """
            
        """
        
        KilowattPerCentimeter = 'kilowatt_per_centimeter'
        """
            
        """
        
        MegawattPerCentimeter = 'megawatt_per_centimeter'
        """
            
        """
        
        GigawattPerCentimeter = 'gigawatt_per_centimeter'
        """
            
        """
        
        MilliwattPerMillimeter = 'milliwatt_per_millimeter'
        """
            
        """
        
        KilowattPerMillimeter = 'kilowatt_per_millimeter'
        """
            
        """
        
        MegawattPerMillimeter = 'megawatt_per_millimeter'
        """
            
        """
        
        GigawattPerMillimeter = 'gigawatt_per_millimeter'
        """
            
        """
        
        MilliwattPerInch = 'milliwatt_per_inch'
        """
            
        """
        
        KilowattPerInch = 'kilowatt_per_inch'
        """
            
        """
        
        MegawattPerInch = 'megawatt_per_inch'
        """
            
        """
        
        GigawattPerInch = 'gigawatt_per_inch'
        """
            
        """
        
        MilliwattPerFoot = 'milliwatt_per_foot'
        """
            
        """
        
        KilowattPerFoot = 'kilowatt_per_foot'
        """
            
        """
        
        MegawattPerFoot = 'megawatt_per_foot'
        """
            
        """
        
        GigawattPerFoot = 'gigawatt_per_foot'
        """
            
        """
        

class LinearPowerDensity:
    """
    The Linear Power Density of a substance is its power per unit length.  The term linear density is most often used when describing the characteristics of one-dimensional objects, although linear density can also be used to describe the density of a three-dimensional quantity along one particular dimension.

    Args:
        value (float): The value.
        from_unit (LinearPowerDensityUnits): The LinearPowerDensity unit to create from, The default unit is WattPerMeter
    """
    def __init__(self, value: float, from_unit: LinearPowerDensityUnits = LinearPowerDensityUnits.WattPerMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__watts_per_meter = None
        
        self.__watts_per_centimeter = None
        
        self.__watts_per_millimeter = None
        
        self.__watts_per_inch = None
        
        self.__watts_per_foot = None
        
        self.__milliwatts_per_meter = None
        
        self.__kilowatts_per_meter = None
        
        self.__megawatts_per_meter = None
        
        self.__gigawatts_per_meter = None
        
        self.__milliwatts_per_centimeter = None
        
        self.__kilowatts_per_centimeter = None
        
        self.__megawatts_per_centimeter = None
        
        self.__gigawatts_per_centimeter = None
        
        self.__milliwatts_per_millimeter = None
        
        self.__kilowatts_per_millimeter = None
        
        self.__megawatts_per_millimeter = None
        
        self.__gigawatts_per_millimeter = None
        
        self.__milliwatts_per_inch = None
        
        self.__kilowatts_per_inch = None
        
        self.__megawatts_per_inch = None
        
        self.__gigawatts_per_inch = None
        
        self.__milliwatts_per_foot = None
        
        self.__kilowatts_per_foot = None
        
        self.__megawatts_per_foot = None
        
        self.__gigawatts_per_foot = None
        

    def __convert_from_base(self, from_unit: LinearPowerDensityUnits) -> float:
        value = self.__value
        
        if from_unit == LinearPowerDensityUnits.WattPerMeter:
            return (value)
        
        if from_unit == LinearPowerDensityUnits.WattPerCentimeter:
            return (value / 1e2)
        
        if from_unit == LinearPowerDensityUnits.WattPerMillimeter:
            return (value / 1e3)
        
        if from_unit == LinearPowerDensityUnits.WattPerInch:
            return (value / 39.37007874)
        
        if from_unit == LinearPowerDensityUnits.WattPerFoot:
            return (value / 3.280839895)
        
        if from_unit == LinearPowerDensityUnits.MilliwattPerMeter:
            return ((value) / 0.001)
        
        if from_unit == LinearPowerDensityUnits.KilowattPerMeter:
            return ((value) / 1000.0)
        
        if from_unit == LinearPowerDensityUnits.MegawattPerMeter:
            return ((value) / 1000000.0)
        
        if from_unit == LinearPowerDensityUnits.GigawattPerMeter:
            return ((value) / 1000000000.0)
        
        if from_unit == LinearPowerDensityUnits.MilliwattPerCentimeter:
            return ((value / 1e2) / 0.001)
        
        if from_unit == LinearPowerDensityUnits.KilowattPerCentimeter:
            return ((value / 1e2) / 1000.0)
        
        if from_unit == LinearPowerDensityUnits.MegawattPerCentimeter:
            return ((value / 1e2) / 1000000.0)
        
        if from_unit == LinearPowerDensityUnits.GigawattPerCentimeter:
            return ((value / 1e2) / 1000000000.0)
        
        if from_unit == LinearPowerDensityUnits.MilliwattPerMillimeter:
            return ((value / 1e3) / 0.001)
        
        if from_unit == LinearPowerDensityUnits.KilowattPerMillimeter:
            return ((value / 1e3) / 1000.0)
        
        if from_unit == LinearPowerDensityUnits.MegawattPerMillimeter:
            return ((value / 1e3) / 1000000.0)
        
        if from_unit == LinearPowerDensityUnits.GigawattPerMillimeter:
            return ((value / 1e3) / 1000000000.0)
        
        if from_unit == LinearPowerDensityUnits.MilliwattPerInch:
            return ((value / 39.37007874) / 0.001)
        
        if from_unit == LinearPowerDensityUnits.KilowattPerInch:
            return ((value / 39.37007874) / 1000.0)
        
        if from_unit == LinearPowerDensityUnits.MegawattPerInch:
            return ((value / 39.37007874) / 1000000.0)
        
        if from_unit == LinearPowerDensityUnits.GigawattPerInch:
            return ((value / 39.37007874) / 1000000000.0)
        
        if from_unit == LinearPowerDensityUnits.MilliwattPerFoot:
            return ((value / 3.280839895) / 0.001)
        
        if from_unit == LinearPowerDensityUnits.KilowattPerFoot:
            return ((value / 3.280839895) / 1000.0)
        
        if from_unit == LinearPowerDensityUnits.MegawattPerFoot:
            return ((value / 3.280839895) / 1000000.0)
        
        if from_unit == LinearPowerDensityUnits.GigawattPerFoot:
            return ((value / 3.280839895) / 1000000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LinearPowerDensityUnits) -> float:
        
        if to_unit == LinearPowerDensityUnits.WattPerMeter:
            return (value)
        
        if to_unit == LinearPowerDensityUnits.WattPerCentimeter:
            return (value * 1e2)
        
        if to_unit == LinearPowerDensityUnits.WattPerMillimeter:
            return (value * 1e3)
        
        if to_unit == LinearPowerDensityUnits.WattPerInch:
            return (value * 39.37007874)
        
        if to_unit == LinearPowerDensityUnits.WattPerFoot:
            return (value * 3.280839895)
        
        if to_unit == LinearPowerDensityUnits.MilliwattPerMeter:
            return ((value) * 0.001)
        
        if to_unit == LinearPowerDensityUnits.KilowattPerMeter:
            return ((value) * 1000.0)
        
        if to_unit == LinearPowerDensityUnits.MegawattPerMeter:
            return ((value) * 1000000.0)
        
        if to_unit == LinearPowerDensityUnits.GigawattPerMeter:
            return ((value) * 1000000000.0)
        
        if to_unit == LinearPowerDensityUnits.MilliwattPerCentimeter:
            return ((value * 1e2) * 0.001)
        
        if to_unit == LinearPowerDensityUnits.KilowattPerCentimeter:
            return ((value * 1e2) * 1000.0)
        
        if to_unit == LinearPowerDensityUnits.MegawattPerCentimeter:
            return ((value * 1e2) * 1000000.0)
        
        if to_unit == LinearPowerDensityUnits.GigawattPerCentimeter:
            return ((value * 1e2) * 1000000000.0)
        
        if to_unit == LinearPowerDensityUnits.MilliwattPerMillimeter:
            return ((value * 1e3) * 0.001)
        
        if to_unit == LinearPowerDensityUnits.KilowattPerMillimeter:
            return ((value * 1e3) * 1000.0)
        
        if to_unit == LinearPowerDensityUnits.MegawattPerMillimeter:
            return ((value * 1e3) * 1000000.0)
        
        if to_unit == LinearPowerDensityUnits.GigawattPerMillimeter:
            return ((value * 1e3) * 1000000000.0)
        
        if to_unit == LinearPowerDensityUnits.MilliwattPerInch:
            return ((value * 39.37007874) * 0.001)
        
        if to_unit == LinearPowerDensityUnits.KilowattPerInch:
            return ((value * 39.37007874) * 1000.0)
        
        if to_unit == LinearPowerDensityUnits.MegawattPerInch:
            return ((value * 39.37007874) * 1000000.0)
        
        if to_unit == LinearPowerDensityUnits.GigawattPerInch:
            return ((value * 39.37007874) * 1000000000.0)
        
        if to_unit == LinearPowerDensityUnits.MilliwattPerFoot:
            return ((value * 3.280839895) * 0.001)
        
        if to_unit == LinearPowerDensityUnits.KilowattPerFoot:
            return ((value * 3.280839895) * 1000.0)
        
        if to_unit == LinearPowerDensityUnits.MegawattPerFoot:
            return ((value * 3.280839895) * 1000000.0)
        
        if to_unit == LinearPowerDensityUnits.GigawattPerFoot:
            return ((value * 3.280839895) * 1000000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_watts_per_meter(watts_per_meter: float):
        """
        Create a new instance of LinearPowerDensity from a value in watts_per_meter.

        

        :param meters: The LinearPowerDensity value in watts_per_meter.
        :type watts_per_meter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(watts_per_meter, LinearPowerDensityUnits.WattPerMeter)

    
    @staticmethod
    def from_watts_per_centimeter(watts_per_centimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in watts_per_centimeter.

        

        :param meters: The LinearPowerDensity value in watts_per_centimeter.
        :type watts_per_centimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(watts_per_centimeter, LinearPowerDensityUnits.WattPerCentimeter)

    
    @staticmethod
    def from_watts_per_millimeter(watts_per_millimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in watts_per_millimeter.

        

        :param meters: The LinearPowerDensity value in watts_per_millimeter.
        :type watts_per_millimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(watts_per_millimeter, LinearPowerDensityUnits.WattPerMillimeter)

    
    @staticmethod
    def from_watts_per_inch(watts_per_inch: float):
        """
        Create a new instance of LinearPowerDensity from a value in watts_per_inch.

        

        :param meters: The LinearPowerDensity value in watts_per_inch.
        :type watts_per_inch: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(watts_per_inch, LinearPowerDensityUnits.WattPerInch)

    
    @staticmethod
    def from_watts_per_foot(watts_per_foot: float):
        """
        Create a new instance of LinearPowerDensity from a value in watts_per_foot.

        

        :param meters: The LinearPowerDensity value in watts_per_foot.
        :type watts_per_foot: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(watts_per_foot, LinearPowerDensityUnits.WattPerFoot)

    
    @staticmethod
    def from_milliwatts_per_meter(milliwatts_per_meter: float):
        """
        Create a new instance of LinearPowerDensity from a value in milliwatts_per_meter.

        

        :param meters: The LinearPowerDensity value in milliwatts_per_meter.
        :type milliwatts_per_meter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(milliwatts_per_meter, LinearPowerDensityUnits.MilliwattPerMeter)

    
    @staticmethod
    def from_kilowatts_per_meter(kilowatts_per_meter: float):
        """
        Create a new instance of LinearPowerDensity from a value in kilowatts_per_meter.

        

        :param meters: The LinearPowerDensity value in kilowatts_per_meter.
        :type kilowatts_per_meter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(kilowatts_per_meter, LinearPowerDensityUnits.KilowattPerMeter)

    
    @staticmethod
    def from_megawatts_per_meter(megawatts_per_meter: float):
        """
        Create a new instance of LinearPowerDensity from a value in megawatts_per_meter.

        

        :param meters: The LinearPowerDensity value in megawatts_per_meter.
        :type megawatts_per_meter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(megawatts_per_meter, LinearPowerDensityUnits.MegawattPerMeter)

    
    @staticmethod
    def from_gigawatts_per_meter(gigawatts_per_meter: float):
        """
        Create a new instance of LinearPowerDensity from a value in gigawatts_per_meter.

        

        :param meters: The LinearPowerDensity value in gigawatts_per_meter.
        :type gigawatts_per_meter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(gigawatts_per_meter, LinearPowerDensityUnits.GigawattPerMeter)

    
    @staticmethod
    def from_milliwatts_per_centimeter(milliwatts_per_centimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in milliwatts_per_centimeter.

        

        :param meters: The LinearPowerDensity value in milliwatts_per_centimeter.
        :type milliwatts_per_centimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(milliwatts_per_centimeter, LinearPowerDensityUnits.MilliwattPerCentimeter)

    
    @staticmethod
    def from_kilowatts_per_centimeter(kilowatts_per_centimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in kilowatts_per_centimeter.

        

        :param meters: The LinearPowerDensity value in kilowatts_per_centimeter.
        :type kilowatts_per_centimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(kilowatts_per_centimeter, LinearPowerDensityUnits.KilowattPerCentimeter)

    
    @staticmethod
    def from_megawatts_per_centimeter(megawatts_per_centimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in megawatts_per_centimeter.

        

        :param meters: The LinearPowerDensity value in megawatts_per_centimeter.
        :type megawatts_per_centimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(megawatts_per_centimeter, LinearPowerDensityUnits.MegawattPerCentimeter)

    
    @staticmethod
    def from_gigawatts_per_centimeter(gigawatts_per_centimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in gigawatts_per_centimeter.

        

        :param meters: The LinearPowerDensity value in gigawatts_per_centimeter.
        :type gigawatts_per_centimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(gigawatts_per_centimeter, LinearPowerDensityUnits.GigawattPerCentimeter)

    
    @staticmethod
    def from_milliwatts_per_millimeter(milliwatts_per_millimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in milliwatts_per_millimeter.

        

        :param meters: The LinearPowerDensity value in milliwatts_per_millimeter.
        :type milliwatts_per_millimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(milliwatts_per_millimeter, LinearPowerDensityUnits.MilliwattPerMillimeter)

    
    @staticmethod
    def from_kilowatts_per_millimeter(kilowatts_per_millimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in kilowatts_per_millimeter.

        

        :param meters: The LinearPowerDensity value in kilowatts_per_millimeter.
        :type kilowatts_per_millimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(kilowatts_per_millimeter, LinearPowerDensityUnits.KilowattPerMillimeter)

    
    @staticmethod
    def from_megawatts_per_millimeter(megawatts_per_millimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in megawatts_per_millimeter.

        

        :param meters: The LinearPowerDensity value in megawatts_per_millimeter.
        :type megawatts_per_millimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(megawatts_per_millimeter, LinearPowerDensityUnits.MegawattPerMillimeter)

    
    @staticmethod
    def from_gigawatts_per_millimeter(gigawatts_per_millimeter: float):
        """
        Create a new instance of LinearPowerDensity from a value in gigawatts_per_millimeter.

        

        :param meters: The LinearPowerDensity value in gigawatts_per_millimeter.
        :type gigawatts_per_millimeter: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(gigawatts_per_millimeter, LinearPowerDensityUnits.GigawattPerMillimeter)

    
    @staticmethod
    def from_milliwatts_per_inch(milliwatts_per_inch: float):
        """
        Create a new instance of LinearPowerDensity from a value in milliwatts_per_inch.

        

        :param meters: The LinearPowerDensity value in milliwatts_per_inch.
        :type milliwatts_per_inch: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(milliwatts_per_inch, LinearPowerDensityUnits.MilliwattPerInch)

    
    @staticmethod
    def from_kilowatts_per_inch(kilowatts_per_inch: float):
        """
        Create a new instance of LinearPowerDensity from a value in kilowatts_per_inch.

        

        :param meters: The LinearPowerDensity value in kilowatts_per_inch.
        :type kilowatts_per_inch: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(kilowatts_per_inch, LinearPowerDensityUnits.KilowattPerInch)

    
    @staticmethod
    def from_megawatts_per_inch(megawatts_per_inch: float):
        """
        Create a new instance of LinearPowerDensity from a value in megawatts_per_inch.

        

        :param meters: The LinearPowerDensity value in megawatts_per_inch.
        :type megawatts_per_inch: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(megawatts_per_inch, LinearPowerDensityUnits.MegawattPerInch)

    
    @staticmethod
    def from_gigawatts_per_inch(gigawatts_per_inch: float):
        """
        Create a new instance of LinearPowerDensity from a value in gigawatts_per_inch.

        

        :param meters: The LinearPowerDensity value in gigawatts_per_inch.
        :type gigawatts_per_inch: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(gigawatts_per_inch, LinearPowerDensityUnits.GigawattPerInch)

    
    @staticmethod
    def from_milliwatts_per_foot(milliwatts_per_foot: float):
        """
        Create a new instance of LinearPowerDensity from a value in milliwatts_per_foot.

        

        :param meters: The LinearPowerDensity value in milliwatts_per_foot.
        :type milliwatts_per_foot: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(milliwatts_per_foot, LinearPowerDensityUnits.MilliwattPerFoot)

    
    @staticmethod
    def from_kilowatts_per_foot(kilowatts_per_foot: float):
        """
        Create a new instance of LinearPowerDensity from a value in kilowatts_per_foot.

        

        :param meters: The LinearPowerDensity value in kilowatts_per_foot.
        :type kilowatts_per_foot: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(kilowatts_per_foot, LinearPowerDensityUnits.KilowattPerFoot)

    
    @staticmethod
    def from_megawatts_per_foot(megawatts_per_foot: float):
        """
        Create a new instance of LinearPowerDensity from a value in megawatts_per_foot.

        

        :param meters: The LinearPowerDensity value in megawatts_per_foot.
        :type megawatts_per_foot: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(megawatts_per_foot, LinearPowerDensityUnits.MegawattPerFoot)

    
    @staticmethod
    def from_gigawatts_per_foot(gigawatts_per_foot: float):
        """
        Create a new instance of LinearPowerDensity from a value in gigawatts_per_foot.

        

        :param meters: The LinearPowerDensity value in gigawatts_per_foot.
        :type gigawatts_per_foot: float
        :return: A new instance of LinearPowerDensity.
        :rtype: LinearPowerDensity
        """
        return LinearPowerDensity(gigawatts_per_foot, LinearPowerDensityUnits.GigawattPerFoot)

    
    @property
    def watts_per_meter(self) -> float:
        """
        
        """
        if self.__watts_per_meter != None:
            return self.__watts_per_meter
        self.__watts_per_meter = self.__convert_from_base(LinearPowerDensityUnits.WattPerMeter)
        return self.__watts_per_meter

    
    @property
    def watts_per_centimeter(self) -> float:
        """
        
        """
        if self.__watts_per_centimeter != None:
            return self.__watts_per_centimeter
        self.__watts_per_centimeter = self.__convert_from_base(LinearPowerDensityUnits.WattPerCentimeter)
        return self.__watts_per_centimeter

    
    @property
    def watts_per_millimeter(self) -> float:
        """
        
        """
        if self.__watts_per_millimeter != None:
            return self.__watts_per_millimeter
        self.__watts_per_millimeter = self.__convert_from_base(LinearPowerDensityUnits.WattPerMillimeter)
        return self.__watts_per_millimeter

    
    @property
    def watts_per_inch(self) -> float:
        """
        
        """
        if self.__watts_per_inch != None:
            return self.__watts_per_inch
        self.__watts_per_inch = self.__convert_from_base(LinearPowerDensityUnits.WattPerInch)
        return self.__watts_per_inch

    
    @property
    def watts_per_foot(self) -> float:
        """
        
        """
        if self.__watts_per_foot != None:
            return self.__watts_per_foot
        self.__watts_per_foot = self.__convert_from_base(LinearPowerDensityUnits.WattPerFoot)
        return self.__watts_per_foot

    
    @property
    def milliwatts_per_meter(self) -> float:
        """
        
        """
        if self.__milliwatts_per_meter != None:
            return self.__milliwatts_per_meter
        self.__milliwatts_per_meter = self.__convert_from_base(LinearPowerDensityUnits.MilliwattPerMeter)
        return self.__milliwatts_per_meter

    
    @property
    def kilowatts_per_meter(self) -> float:
        """
        
        """
        if self.__kilowatts_per_meter != None:
            return self.__kilowatts_per_meter
        self.__kilowatts_per_meter = self.__convert_from_base(LinearPowerDensityUnits.KilowattPerMeter)
        return self.__kilowatts_per_meter

    
    @property
    def megawatts_per_meter(self) -> float:
        """
        
        """
        if self.__megawatts_per_meter != None:
            return self.__megawatts_per_meter
        self.__megawatts_per_meter = self.__convert_from_base(LinearPowerDensityUnits.MegawattPerMeter)
        return self.__megawatts_per_meter

    
    @property
    def gigawatts_per_meter(self) -> float:
        """
        
        """
        if self.__gigawatts_per_meter != None:
            return self.__gigawatts_per_meter
        self.__gigawatts_per_meter = self.__convert_from_base(LinearPowerDensityUnits.GigawattPerMeter)
        return self.__gigawatts_per_meter

    
    @property
    def milliwatts_per_centimeter(self) -> float:
        """
        
        """
        if self.__milliwatts_per_centimeter != None:
            return self.__milliwatts_per_centimeter
        self.__milliwatts_per_centimeter = self.__convert_from_base(LinearPowerDensityUnits.MilliwattPerCentimeter)
        return self.__milliwatts_per_centimeter

    
    @property
    def kilowatts_per_centimeter(self) -> float:
        """
        
        """
        if self.__kilowatts_per_centimeter != None:
            return self.__kilowatts_per_centimeter
        self.__kilowatts_per_centimeter = self.__convert_from_base(LinearPowerDensityUnits.KilowattPerCentimeter)
        return self.__kilowatts_per_centimeter

    
    @property
    def megawatts_per_centimeter(self) -> float:
        """
        
        """
        if self.__megawatts_per_centimeter != None:
            return self.__megawatts_per_centimeter
        self.__megawatts_per_centimeter = self.__convert_from_base(LinearPowerDensityUnits.MegawattPerCentimeter)
        return self.__megawatts_per_centimeter

    
    @property
    def gigawatts_per_centimeter(self) -> float:
        """
        
        """
        if self.__gigawatts_per_centimeter != None:
            return self.__gigawatts_per_centimeter
        self.__gigawatts_per_centimeter = self.__convert_from_base(LinearPowerDensityUnits.GigawattPerCentimeter)
        return self.__gigawatts_per_centimeter

    
    @property
    def milliwatts_per_millimeter(self) -> float:
        """
        
        """
        if self.__milliwatts_per_millimeter != None:
            return self.__milliwatts_per_millimeter
        self.__milliwatts_per_millimeter = self.__convert_from_base(LinearPowerDensityUnits.MilliwattPerMillimeter)
        return self.__milliwatts_per_millimeter

    
    @property
    def kilowatts_per_millimeter(self) -> float:
        """
        
        """
        if self.__kilowatts_per_millimeter != None:
            return self.__kilowatts_per_millimeter
        self.__kilowatts_per_millimeter = self.__convert_from_base(LinearPowerDensityUnits.KilowattPerMillimeter)
        return self.__kilowatts_per_millimeter

    
    @property
    def megawatts_per_millimeter(self) -> float:
        """
        
        """
        if self.__megawatts_per_millimeter != None:
            return self.__megawatts_per_millimeter
        self.__megawatts_per_millimeter = self.__convert_from_base(LinearPowerDensityUnits.MegawattPerMillimeter)
        return self.__megawatts_per_millimeter

    
    @property
    def gigawatts_per_millimeter(self) -> float:
        """
        
        """
        if self.__gigawatts_per_millimeter != None:
            return self.__gigawatts_per_millimeter
        self.__gigawatts_per_millimeter = self.__convert_from_base(LinearPowerDensityUnits.GigawattPerMillimeter)
        return self.__gigawatts_per_millimeter

    
    @property
    def milliwatts_per_inch(self) -> float:
        """
        
        """
        if self.__milliwatts_per_inch != None:
            return self.__milliwatts_per_inch
        self.__milliwatts_per_inch = self.__convert_from_base(LinearPowerDensityUnits.MilliwattPerInch)
        return self.__milliwatts_per_inch

    
    @property
    def kilowatts_per_inch(self) -> float:
        """
        
        """
        if self.__kilowatts_per_inch != None:
            return self.__kilowatts_per_inch
        self.__kilowatts_per_inch = self.__convert_from_base(LinearPowerDensityUnits.KilowattPerInch)
        return self.__kilowatts_per_inch

    
    @property
    def megawatts_per_inch(self) -> float:
        """
        
        """
        if self.__megawatts_per_inch != None:
            return self.__megawatts_per_inch
        self.__megawatts_per_inch = self.__convert_from_base(LinearPowerDensityUnits.MegawattPerInch)
        return self.__megawatts_per_inch

    
    @property
    def gigawatts_per_inch(self) -> float:
        """
        
        """
        if self.__gigawatts_per_inch != None:
            return self.__gigawatts_per_inch
        self.__gigawatts_per_inch = self.__convert_from_base(LinearPowerDensityUnits.GigawattPerInch)
        return self.__gigawatts_per_inch

    
    @property
    def milliwatts_per_foot(self) -> float:
        """
        
        """
        if self.__milliwatts_per_foot != None:
            return self.__milliwatts_per_foot
        self.__milliwatts_per_foot = self.__convert_from_base(LinearPowerDensityUnits.MilliwattPerFoot)
        return self.__milliwatts_per_foot

    
    @property
    def kilowatts_per_foot(self) -> float:
        """
        
        """
        if self.__kilowatts_per_foot != None:
            return self.__kilowatts_per_foot
        self.__kilowatts_per_foot = self.__convert_from_base(LinearPowerDensityUnits.KilowattPerFoot)
        return self.__kilowatts_per_foot

    
    @property
    def megawatts_per_foot(self) -> float:
        """
        
        """
        if self.__megawatts_per_foot != None:
            return self.__megawatts_per_foot
        self.__megawatts_per_foot = self.__convert_from_base(LinearPowerDensityUnits.MegawattPerFoot)
        return self.__megawatts_per_foot

    
    @property
    def gigawatts_per_foot(self) -> float:
        """
        
        """
        if self.__gigawatts_per_foot != None:
            return self.__gigawatts_per_foot
        self.__gigawatts_per_foot = self.__convert_from_base(LinearPowerDensityUnits.GigawattPerFoot)
        return self.__gigawatts_per_foot

    
    def to_string(self, unit: LinearPowerDensityUnits = LinearPowerDensityUnits.WattPerMeter) -> string:
        """
        Format the LinearPowerDensity to string.
        Note! the default format for LinearPowerDensity is WattPerMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == LinearPowerDensityUnits.WattPerMeter:
            return f"""{self.watts_per_meter} W/m"""
        
        if unit == LinearPowerDensityUnits.WattPerCentimeter:
            return f"""{self.watts_per_centimeter} W/cm"""
        
        if unit == LinearPowerDensityUnits.WattPerMillimeter:
            return f"""{self.watts_per_millimeter} W/mm"""
        
        if unit == LinearPowerDensityUnits.WattPerInch:
            return f"""{self.watts_per_inch} W/in"""
        
        if unit == LinearPowerDensityUnits.WattPerFoot:
            return f"""{self.watts_per_foot} W/ft"""
        
        if unit == LinearPowerDensityUnits.MilliwattPerMeter:
            return f"""{self.milliwatts_per_meter} """
        
        if unit == LinearPowerDensityUnits.KilowattPerMeter:
            return f"""{self.kilowatts_per_meter} """
        
        if unit == LinearPowerDensityUnits.MegawattPerMeter:
            return f"""{self.megawatts_per_meter} """
        
        if unit == LinearPowerDensityUnits.GigawattPerMeter:
            return f"""{self.gigawatts_per_meter} """
        
        if unit == LinearPowerDensityUnits.MilliwattPerCentimeter:
            return f"""{self.milliwatts_per_centimeter} """
        
        if unit == LinearPowerDensityUnits.KilowattPerCentimeter:
            return f"""{self.kilowatts_per_centimeter} """
        
        if unit == LinearPowerDensityUnits.MegawattPerCentimeter:
            return f"""{self.megawatts_per_centimeter} """
        
        if unit == LinearPowerDensityUnits.GigawattPerCentimeter:
            return f"""{self.gigawatts_per_centimeter} """
        
        if unit == LinearPowerDensityUnits.MilliwattPerMillimeter:
            return f"""{self.milliwatts_per_millimeter} """
        
        if unit == LinearPowerDensityUnits.KilowattPerMillimeter:
            return f"""{self.kilowatts_per_millimeter} """
        
        if unit == LinearPowerDensityUnits.MegawattPerMillimeter:
            return f"""{self.megawatts_per_millimeter} """
        
        if unit == LinearPowerDensityUnits.GigawattPerMillimeter:
            return f"""{self.gigawatts_per_millimeter} """
        
        if unit == LinearPowerDensityUnits.MilliwattPerInch:
            return f"""{self.milliwatts_per_inch} """
        
        if unit == LinearPowerDensityUnits.KilowattPerInch:
            return f"""{self.kilowatts_per_inch} """
        
        if unit == LinearPowerDensityUnits.MegawattPerInch:
            return f"""{self.megawatts_per_inch} """
        
        if unit == LinearPowerDensityUnits.GigawattPerInch:
            return f"""{self.gigawatts_per_inch} """
        
        if unit == LinearPowerDensityUnits.MilliwattPerFoot:
            return f"""{self.milliwatts_per_foot} """
        
        if unit == LinearPowerDensityUnits.KilowattPerFoot:
            return f"""{self.kilowatts_per_foot} """
        
        if unit == LinearPowerDensityUnits.MegawattPerFoot:
            return f"""{self.megawatts_per_foot} """
        
        if unit == LinearPowerDensityUnits.GigawattPerFoot:
            return f"""{self.gigawatts_per_foot} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: LinearPowerDensityUnits = LinearPowerDensityUnits.WattPerMeter) -> string:
        """
        Get LinearPowerDensity unit abbreviation.
        Note! the default abbreviation for LinearPowerDensity is WattPerMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LinearPowerDensityUnits.WattPerMeter:
            return """W/m"""
        
        if unit_abbreviation == LinearPowerDensityUnits.WattPerCentimeter:
            return """W/cm"""
        
        if unit_abbreviation == LinearPowerDensityUnits.WattPerMillimeter:
            return """W/mm"""
        
        if unit_abbreviation == LinearPowerDensityUnits.WattPerInch:
            return """W/in"""
        
        if unit_abbreviation == LinearPowerDensityUnits.WattPerFoot:
            return """W/ft"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerMeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.KilowattPerMeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MegawattPerMeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.GigawattPerMeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerCentimeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.KilowattPerCentimeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MegawattPerCentimeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.GigawattPerCentimeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerMillimeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.KilowattPerMillimeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MegawattPerMillimeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.GigawattPerMillimeter:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerInch:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.KilowattPerInch:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MegawattPerInch:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.GigawattPerInch:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerFoot:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.KilowattPerFoot:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.MegawattPerFoot:
            return """"""
        
        if unit_abbreviation == LinearPowerDensityUnits.GigawattPerFoot:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for +: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return LinearPowerDensity(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for *: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return LinearPowerDensity(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for -: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return LinearPowerDensity(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for /: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return LinearPowerDensity(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for %: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return LinearPowerDensity(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for **: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return LinearPowerDensity(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for ==: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for <: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for >: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for <=: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, LinearPowerDensity):
            raise TypeError("unsupported operand type(s) for >=: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value